.. include:: overall.md
   :parser: myst_parser.sphinx_

Table of contents
=================
.. toctree::
   :maxdepth: 2

   guide/index
   tutorial/index
   develop
   external

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`